@@ -6,4 +6,4 @@ ActionT = TypeVar("ActionT", bound=BaseModel)
 
 
 class ActionMixin(BaseModel, Generic[ActionT]):
-    action: Annotated[ActionT, Field(..., description="Action.")]
+    action: Annotated[ActionT, Field(..., description="Action")]
