@@ -229,7 +229,7 @@ class Factory:
                 if not isinstance(action, ResourceOperationActions):
                     raise HTTPException(
                         status_code=status.HTTP_400_BAD_REQUEST,
-                        detail=f"Invalid resource_operation_action in request's state: {action}.",
+                        detail=f"Invalid resource_operation_action in request's state: {action}",
                     )
                 return action
 
@@ -243,7 +243,7 @@ class Factory:
                 if not isinstance(action, model):
                     raise HTTPException(
                         status_code=status.HTTP_400_BAD_REQUEST,
-                        detail=f"Mismatched 'resource_operation_action' type, expected '{model.__name__}' but received '{type(action).__name__}'.",
+                        detail=f"Mismatched 'resource_operation_action' type, expected '{model.__name__}' but received '{type(action).__name__}'",
                     )
                 return action
 
@@ -295,14 +295,14 @@ class Factory:
             if action is None:
                 raise HTTPException(
                     status_code=status.HTTP_400_BAD_REQUEST,
-                    detail="Unable to determine resource operation action.",
+                    detail="Unable to determine resource operation action",
                 )
 
             if not strict:
                 if not isinstance(action, ResourceOperationActions):
                     raise HTTPException(
                         status_code=status.HTTP_400_BAD_REQUEST,
-                        detail=f"Invalid resource_operation_action in request's state: {action}.",
+                        detail=f"Invalid resource_operation_action in request's state: {action}",
                     )
                 return action
 
@@ -316,7 +316,7 @@ class Factory:
                 if not isinstance(action, model):
                     raise HTTPException(
                         status_code=status.HTTP_400_BAD_REQUEST,
-                        detail=f"Mismatched 'resource_operation_action' type, expected '{model.__name__}' but received '{type(action).__name__}'.",
+                        detail=f"Mismatched 'resource_operation_action' type, expected '{model.__name__}' but received '{type(action).__name__}'",
                     )
                 return action
 
