@@ -1,4 +1,5 @@
-from fastapi import Request, Header
+from fastapi import Header
+from fastapi.requests import HTTPConnection
 from typing import Callable
 from uuid import UUID
 from maleo.enums.connection import Header as HeaderEnum
@@ -12,14 +13,14 @@ def get_operation_id(
 ) -> Callable[..., UUID]:
 
     def dependency(
-        request: Request,
+        conn: HTTPConnection,
         # the following operation_id is for documentation purpose only
         operation_id: OptionalUUID = Header(
             None,
             alias=HeaderEnum.X_OPERATION_ID.value,
-            description="Operation ID Header",
+            description="Operation's ID",
         ),
     ) -> UUID:
-        return extract_operation_id(source, request=request, generate=generate)
+        return extract_operation_id(source, conn=conn, generate=generate)
 
     return dependency
