@@ -1,12 +1,12 @@
 from copy import deepcopy
 from typing import Generic, Literal, Optional, Type, Union, overload
 from uuid import UUID
+from maleo.types.boolean import BooleanT
 from ..application import ApplicationContext
 from ..connection import OptionalConnectionContext
 from ..data import ModelDataT
 from ..error import OptionalAnyErrorT, AnyErrorT
 from ..metadata import ModelMetadataT
-from ..mixins.general import SuccessT
 from ..pagination import PaginationT
 from ..resource import Resource
 from ..response import (
@@ -23,8 +23,8 @@ from ..response import (
     UpdateMultipleDataResponse,
     DeleteMultipleDataResponse,
 )
-from ..security.authentication import OptionalAnyAuthenticationT
-from ..security.authorization import OptionalAuthorizationT
+from ..security.authentication import OptionalAnyAuthentication
+from ..security.authorization import OptionalAnyAuthorization
 from ..security.impersonation import OptionalImpersonation
 from .action.resource import (
     AnyResourceOperationActionT,
@@ -53,20 +53,16 @@ class ResourceOperation(
     BaseOperation[
         AnyResourceOperationActionT,
         Resource,
-        SuccessT,
+        BooleanT,
         OptionalAnyErrorT,
         OptionalConnectionContext,
-        OptionalAnyAuthenticationT,
-        OptionalAuthorizationT,
         ResponseT,
         None,
     ],
     Generic[
         AnyResourceOperationActionT,
-        SuccessT,
+        BooleanT,
         OptionalAnyErrorT,
-        OptionalAnyAuthenticationT,
-        OptionalAuthorizationT,
         ResponseT,
     ],
 ):
@@ -79,15 +75,11 @@ class FailedResourceOperation(
         AnyResourceOperationActionT,
         Literal[False],
         AnyErrorT,
-        OptionalAnyAuthenticationT,
-        OptionalAuthorizationT,
         ErrorResponseT,
     ],
     Generic[
         AnyResourceOperationActionT,
         AnyErrorT,
-        OptionalAnyAuthenticationT,
-        OptionalAuthorizationT,
         ErrorResponseT,
     ],
 ):
@@ -98,14 +90,10 @@ class CreateFailedResourceOperation(
     FailedResourceOperation[
         CreateResourceOperationAction,
         AnyErrorT,
-        OptionalAnyAuthenticationT,
-        OptionalAuthorizationT,
         ErrorResponseT,
     ],
     Generic[
         AnyErrorT,
-        OptionalAnyAuthenticationT,
-        OptionalAuthorizationT,
         ErrorResponseT,
     ],
 ):
@@ -116,14 +104,10 @@ class ReadFailedResourceOperation(
     FailedResourceOperation[
         ReadResourceOperationAction,
         AnyErrorT,
-        OptionalAnyAuthenticationT,
-        OptionalAuthorizationT,
         ErrorResponseT,
     ],
     Generic[
         AnyErrorT,
-        OptionalAnyAuthenticationT,
-        OptionalAuthorizationT,
         ErrorResponseT,
     ],
 ):
@@ -134,14 +118,10 @@ class UpdateFailedResourceOperation(
     FailedResourceOperation[
         UpdateResourceOperationAction,
         AnyErrorT,
-        OptionalAnyAuthenticationT,
-        OptionalAuthorizationT,
         ErrorResponseT,
     ],
     Generic[
         AnyErrorT,
-        OptionalAnyAuthenticationT,
-        OptionalAuthorizationT,
         ErrorResponseT,
     ],
 ):
@@ -152,14 +132,10 @@ class DeleteFailedResourceOperation(
     FailedResourceOperation[
         DeleteResourceOperationAction,
         AnyErrorT,
-        OptionalAnyAuthenticationT,
-        OptionalAuthorizationT,
         ErrorResponseT,
     ],
     Generic[
         AnyErrorT,
-        OptionalAnyAuthenticationT,
-        OptionalAuthorizationT,
         ErrorResponseT,
     ],
 ):
@@ -171,14 +147,10 @@ class SuccessfulResourceOperation(
         AnyResourceOperationActionT,
         Literal[True],
         None,
-        OptionalAnyAuthenticationT,
-        OptionalAuthorizationT,
         SuccessResponseT,
     ],
     Generic[
         AnyResourceOperationActionT,
-        OptionalAnyAuthenticationT,
-        OptionalAuthorizationT,
         SuccessResponseT,
     ],
 ):
@@ -189,14 +161,10 @@ class SuccessfulResourceOperation(
 class NoDataResourceOperation(
     SuccessfulResourceOperation[
         AnyResourceOperationActionT,
-        OptionalAnyAuthenticationT,
-        OptionalAuthorizationT,
         NoDataResponse[ModelMetadataT],
     ],
     Generic[
         AnyResourceOperationActionT,
-        OptionalAnyAuthenticationT,
-        OptionalAuthorizationT,
         ModelMetadataT,
     ],
 ):
@@ -206,13 +174,9 @@ class NoDataResourceOperation(
 class CreateSingleResourceOperation(
     SuccessfulResourceOperation[
         CreateResourceOperationAction,
-        OptionalAnyAuthenticationT,
-        OptionalAuthorizationT,
         CreateSingleDataResponse[ModelDataT, ModelMetadataT],
     ],
     Generic[
-        OptionalAnyAuthenticationT,
-        OptionalAuthorizationT,
         ModelDataT,
         ModelMetadataT,
     ],
@@ -223,13 +187,9 @@ class CreateSingleResourceOperation(
 class ReadSingleResourceOperation(
     SuccessfulResourceOperation[
         ReadResourceOperationAction,
-        OptionalAnyAuthenticationT,
-        OptionalAuthorizationT,
         ReadSingleDataResponse[ModelDataT, ModelMetadataT],
     ],
     Generic[
-        OptionalAnyAuthenticationT,
-        OptionalAuthorizationT,
         ModelDataT,
         ModelMetadataT,
     ],
@@ -240,13 +200,9 @@ class ReadSingleResourceOperation(
 class UpdateSingleResourceOperation(
     SuccessfulResourceOperation[
         UpdateResourceOperationAction,
-        OptionalAnyAuthenticationT,
-        OptionalAuthorizationT,
         UpdateSingleDataResponse[ModelDataT, ModelMetadataT],
     ],
     Generic[
-        OptionalAnyAuthenticationT,
-        OptionalAuthorizationT,
         ModelDataT,
         ModelMetadataT,
     ],
@@ -257,13 +213,9 @@ class UpdateSingleResourceOperation(
 class DeleteSingleResourceOperation(
     SuccessfulResourceOperation[
         DeleteResourceOperationAction,
-        OptionalAnyAuthenticationT,
-        OptionalAuthorizationT,
         DeleteSingleDataResponse[ModelDataT, ModelMetadataT],
     ],
     Generic[
-        OptionalAnyAuthenticationT,
-        OptionalAuthorizationT,
         ModelDataT,
         ModelMetadataT,
     ],
@@ -274,13 +226,9 @@ class DeleteSingleResourceOperation(
 class CreateMultipleResourceOperation(
     SuccessfulResourceOperation[
         CreateResourceOperationAction,
-        OptionalAnyAuthenticationT,
-        OptionalAuthorizationT,
         CreateMultipleDataResponse[ModelDataT, PaginationT, ModelMetadataT],
     ],
     Generic[
-        OptionalAnyAuthenticationT,
-        OptionalAuthorizationT,
         ModelDataT,
         PaginationT,
         ModelMetadataT,
@@ -292,13 +240,9 @@ class CreateMultipleResourceOperation(
 class ReadMultipleResourceOperation(
     SuccessfulResourceOperation[
         ReadResourceOperationAction,
-        OptionalAnyAuthenticationT,
-        OptionalAuthorizationT,
         ReadMultipleDataResponse[ModelDataT, PaginationT, ModelMetadataT],
     ],
     Generic[
-        OptionalAnyAuthenticationT,
-        OptionalAuthorizationT,
         ModelDataT,
         PaginationT,
         ModelMetadataT,
@@ -310,13 +254,9 @@ class ReadMultipleResourceOperation(
 class UpdateMultipleResourceOperation(
     SuccessfulResourceOperation[
         UpdateResourceOperationAction,
-        OptionalAnyAuthenticationT,
-        OptionalAuthorizationT,
         UpdateMultipleDataResponse[ModelDataT, PaginationT, ModelMetadataT],
     ],
     Generic[
-        OptionalAnyAuthenticationT,
-        OptionalAuthorizationT,
         ModelDataT,
         PaginationT,
         ModelMetadataT,
@@ -328,13 +268,9 @@ class UpdateMultipleResourceOperation(
 class DeleteMultipleResourceOperation(
     SuccessfulResourceOperation[
         DeleteResourceOperationAction,
-        OptionalAnyAuthenticationT,
-        OptionalAuthorizationT,
         DeleteMultipleDataResponse[ModelDataT, PaginationT, ModelMetadataT],
     ],
     Generic[
-        OptionalAnyAuthenticationT,
-        OptionalAuthorizationT,
         ModelDataT,
         PaginationT,
         ModelMetadataT,
@@ -343,18 +279,12 @@ class DeleteMultipleResourceOperation(
     pass
 
 
-class FailedFactory(
-    Generic[
-        AnyErrorT, OptionalAnyAuthenticationT, OptionalAuthorizationT, ErrorResponseT
-    ]
-):
+class FailedFactory(Generic[AnyErrorT, ErrorResponseT]):
     @overload
     @classmethod
     def operation_cls_from_action(cls, action: CreateResourceOperationAction) -> Type[
         CreateFailedResourceOperation[
             AnyErrorT,
-            OptionalAnyAuthenticationT,
-            OptionalAuthorizationT,
             ErrorResponseT,
         ]
     ]: ...
@@ -363,8 +293,6 @@ class FailedFactory(
     def operation_cls_from_action(cls, action: ReadResourceOperationAction) -> Type[
         ReadFailedResourceOperation[
             AnyErrorT,
-            OptionalAnyAuthenticationT,
-            OptionalAuthorizationT,
             ErrorResponseT,
         ]
     ]: ...
@@ -373,8 +301,6 @@ class FailedFactory(
     def operation_cls_from_action(cls, action: UpdateResourceOperationAction) -> Type[
         UpdateFailedResourceOperation[
             AnyErrorT,
-            OptionalAnyAuthenticationT,
-            OptionalAuthorizationT,
             ErrorResponseT,
         ]
     ]: ...
@@ -383,8 +309,6 @@ class FailedFactory(
     def operation_cls_from_action(cls, action: DeleteResourceOperationAction) -> Type[
         DeleteFailedResourceOperation[
             AnyErrorT,
-            OptionalAnyAuthenticationT,
-            OptionalAuthorizationT,
             ErrorResponseT,
         ]
     ]: ...
@@ -394,32 +318,24 @@ class FailedFactory(
         Type[
             CreateFailedResourceOperation[
                 AnyErrorT,
-                OptionalAnyAuthenticationT,
-                OptionalAuthorizationT,
                 ErrorResponseT,
             ]
         ],
         Type[
             ReadFailedResourceOperation[
                 AnyErrorT,
-                OptionalAnyAuthenticationT,
-                OptionalAuthorizationT,
                 ErrorResponseT,
             ]
         ],
         Type[
             UpdateFailedResourceOperation[
                 AnyErrorT,
-                OptionalAnyAuthenticationT,
-                OptionalAuthorizationT,
                 ErrorResponseT,
             ]
         ],
         Type[
             DeleteFailedResourceOperation[
                 AnyErrorT,
-                OptionalAnyAuthenticationT,
-                OptionalAuthorizationT,
                 ErrorResponseT,
             ]
         ],
@@ -429,32 +345,24 @@ class FailedFactory(
         Type[
             CreateFailedResourceOperation[
                 AnyErrorT,
-                OptionalAnyAuthenticationT,
-                OptionalAuthorizationT,
                 ErrorResponseT,
             ]
         ],
         Type[
             ReadFailedResourceOperation[
                 AnyErrorT,
-                OptionalAnyAuthenticationT,
-                OptionalAuthorizationT,
                 ErrorResponseT,
             ]
         ],
         Type[
             UpdateFailedResourceOperation[
                 AnyErrorT,
-                OptionalAnyAuthenticationT,
-                OptionalAuthorizationT,
                 ErrorResponseT,
             ]
         ],
         Type[
             DeleteFailedResourceOperation[
                 AnyErrorT,
-                OptionalAnyAuthenticationT,
-                OptionalAuthorizationT,
                 ErrorResponseT,
             ]
         ],
@@ -462,29 +370,21 @@ class FailedFactory(
         if isinstance(action, CreateResourceOperationAction):
             operation_cls = CreateFailedResourceOperation[
                 AnyErrorT,
-                OptionalAnyAuthenticationT,
-                OptionalAuthorizationT,
                 ErrorResponseT,
             ]
         elif isinstance(action, ReadResourceOperationAction):
             operation_cls = ReadFailedResourceOperation[
                 AnyErrorT,
-                OptionalAnyAuthenticationT,
-                OptionalAuthorizationT,
                 ErrorResponseT,
             ]
         elif isinstance(action, UpdateResourceOperationAction):
             operation_cls = UpdateFailedResourceOperation[
                 AnyErrorT,
-                OptionalAnyAuthenticationT,
-                OptionalAuthorizationT,
                 ErrorResponseT,
             ]
         elif isinstance(action, DeleteResourceOperationAction):
             operation_cls = DeleteFailedResourceOperation[
                 AnyErrorT,
-                OptionalAnyAuthenticationT,
-                OptionalAuthorizationT,
                 ErrorResponseT,
             ]
         return operation_cls
@@ -497,8 +397,6 @@ class FailedFactory(
     ) -> Type[
         CreateFailedResourceOperation[
             AnyErrorT,
-            OptionalAnyAuthenticationT,
-            OptionalAuthorizationT,
             ErrorResponseT,
         ]
     ]: ...
@@ -510,8 +408,6 @@ class FailedFactory(
     ) -> Type[
         ReadFailedResourceOperation[
             AnyErrorT,
-            OptionalAnyAuthenticationT,
-            OptionalAuthorizationT,
             ErrorResponseT,
         ]
     ]: ...
@@ -523,8 +419,6 @@ class FailedFactory(
     ) -> Type[
         UpdateFailedResourceOperation[
             AnyErrorT,
-            OptionalAnyAuthenticationT,
-            OptionalAuthorizationT,
             ErrorResponseT,
         ]
     ]: ...
@@ -536,8 +430,6 @@ class FailedFactory(
     ) -> Type[
         DeleteFailedResourceOperation[
             AnyErrorT,
-            OptionalAnyAuthenticationT,
-            OptionalAuthorizationT,
             ErrorResponseT,
         ]
     ]: ...
@@ -549,32 +441,24 @@ class FailedFactory(
         Type[
             CreateFailedResourceOperation[
                 AnyErrorT,
-                OptionalAnyAuthenticationT,
-                OptionalAuthorizationT,
                 ErrorResponseT,
             ]
         ],
         Type[
             ReadFailedResourceOperation[
                 AnyErrorT,
-                OptionalAnyAuthenticationT,
-                OptionalAuthorizationT,
                 ErrorResponseT,
             ]
         ],
         Type[
             UpdateFailedResourceOperation[
                 AnyErrorT,
-                OptionalAnyAuthenticationT,
-                OptionalAuthorizationT,
                 ErrorResponseT,
             ]
         ],
         Type[
             DeleteFailedResourceOperation[
                 AnyErrorT,
-                OptionalAnyAuthenticationT,
-                OptionalAuthorizationT,
                 ErrorResponseT,
             ]
         ],
@@ -582,29 +466,21 @@ class FailedFactory(
         if type_ is ResourceOperationType.CREATE:
             operation_cls = CreateFailedResourceOperation[
                 AnyErrorT,
-                OptionalAnyAuthenticationT,
-                OptionalAuthorizationT,
                 ErrorResponseT,
             ]
         elif type_ is ResourceOperationType.READ:
             operation_cls = ReadFailedResourceOperation[
                 AnyErrorT,
-                OptionalAnyAuthenticationT,
-                OptionalAuthorizationT,
                 ErrorResponseT,
             ]
         elif type_ is ResourceOperationType.UPDATE:
             operation_cls = UpdateFailedResourceOperation[
                 AnyErrorT,
-                OptionalAnyAuthenticationT,
-                OptionalAuthorizationT,
                 ErrorResponseT,
             ]
         elif type_ is ResourceOperationType.DELETE:
             operation_cls = DeleteFailedResourceOperation[
                 AnyErrorT,
-                OptionalAnyAuthenticationT,
-                OptionalAuthorizationT,
                 ErrorResponseT,
             ]
         return operation_cls
@@ -623,13 +499,11 @@ class FailedFactory(
         summary: str,
         error: AnyErrorT,
         connection_context: OptionalConnectionContext = None,
-        authentication: OptionalAnyAuthenticationT,
-        authorization: OptionalAuthorizationT,
+        authentication: OptionalAnyAuthentication = None,
+        authorization: OptionalAnyAuthorization = None,
         impersonation: OptionalImpersonation = None,
         response: ErrorResponseT,
-    ) -> CreateFailedResourceOperation[
-        AnyErrorT, OptionalAnyAuthenticationT, OptionalAuthorizationT, ErrorResponseT
-    ]: ...
+    ) -> CreateFailedResourceOperation[AnyErrorT, ErrorResponseT]: ...
     @overload
     @classmethod
     def generate(
@@ -644,13 +518,11 @@ class FailedFactory(
         summary: str,
         error: AnyErrorT,
         connection_context: OptionalConnectionContext = None,
-        authentication: OptionalAnyAuthenticationT,
-        authorization: OptionalAuthorizationT,
+        authentication: OptionalAnyAuthentication = None,
+        authorization: OptionalAnyAuthorization = None,
         impersonation: OptionalImpersonation = None,
         response: ErrorResponseT,
-    ) -> ReadFailedResourceOperation[
-        AnyErrorT, OptionalAnyAuthenticationT, OptionalAuthorizationT, ErrorResponseT
-    ]: ...
+    ) -> ReadFailedResourceOperation[AnyErrorT, ErrorResponseT]: ...
     @overload
     @classmethod
     def generate(
@@ -665,13 +537,11 @@ class FailedFactory(
         summary: str,
         error: AnyErrorT,
         connection_context: OptionalConnectionContext = None,
-        authentication: OptionalAnyAuthenticationT,
-        authorization: OptionalAuthorizationT,
+        authentication: OptionalAnyAuthentication = None,
+        authorization: OptionalAnyAuthorization = None,
         impersonation: OptionalImpersonation = None,
         response: ErrorResponseT,
-    ) -> UpdateFailedResourceOperation[
-        AnyErrorT, OptionalAnyAuthenticationT, OptionalAuthorizationT, ErrorResponseT
-    ]: ...
+    ) -> UpdateFailedResourceOperation[AnyErrorT, ErrorResponseT]: ...
     @overload
     @classmethod
     def generate(
@@ -686,13 +556,11 @@ class FailedFactory(
         summary: str,
         error: AnyErrorT,
         connection_context: OptionalConnectionContext = None,
-        authentication: OptionalAnyAuthenticationT,
-        authorization: OptionalAuthorizationT,
+        authentication: OptionalAnyAuthentication = None,
+        authorization: OptionalAnyAuthorization = None,
         impersonation: OptionalImpersonation = None,
         response: ErrorResponseT,
-    ) -> DeleteFailedResourceOperation[
-        AnyErrorT, OptionalAnyAuthenticationT, OptionalAuthorizationT, ErrorResponseT
-    ]: ...
+    ) -> DeleteFailedResourceOperation[AnyErrorT, ErrorResponseT]: ...
     @overload
     @classmethod
     def generate(
@@ -707,33 +575,25 @@ class FailedFactory(
         summary: str,
         error: AnyErrorT,
         connection_context: OptionalConnectionContext = None,
-        authentication: OptionalAnyAuthenticationT,
-        authorization: OptionalAuthorizationT,
+        authentication: OptionalAnyAuthentication = None,
+        authorization: OptionalAnyAuthorization = None,
         impersonation: OptionalImpersonation = None,
         response: ErrorResponseT,
     ) -> Union[
         CreateFailedResourceOperation[
             AnyErrorT,
-            OptionalAnyAuthenticationT,
-            OptionalAuthorizationT,
             ErrorResponseT,
         ],
         ReadFailedResourceOperation[
             AnyErrorT,
-            OptionalAnyAuthenticationT,
-            OptionalAuthorizationT,
             ErrorResponseT,
         ],
         UpdateFailedResourceOperation[
             AnyErrorT,
-            OptionalAnyAuthenticationT,
-            OptionalAuthorizationT,
             ErrorResponseT,
         ],
         DeleteFailedResourceOperation[
             AnyErrorT,
-            OptionalAnyAuthenticationT,
-            OptionalAuthorizationT,
             ErrorResponseT,
         ],
     ]: ...
@@ -752,13 +612,11 @@ class FailedFactory(
         summary: str,
         error: AnyErrorT,
         connection_context: OptionalConnectionContext = None,
-        authentication: OptionalAnyAuthenticationT,
-        authorization: OptionalAuthorizationT,
+        authentication: OptionalAnyAuthentication = None,
+        authorization: OptionalAnyAuthorization = None,
         impersonation: OptionalImpersonation = None,
         response: ErrorResponseT,
-    ) -> CreateFailedResourceOperation[
-        AnyErrorT, OptionalAnyAuthenticationT, OptionalAuthorizationT, ErrorResponseT
-    ]: ...
+    ) -> CreateFailedResourceOperation[AnyErrorT, ErrorResponseT]: ...
     @overload
     @classmethod
     def generate(
@@ -773,13 +631,11 @@ class FailedFactory(
         summary: str,
         error: AnyErrorT,
         connection_context: OptionalConnectionContext = None,
-        authentication: OptionalAnyAuthenticationT,
-        authorization: OptionalAuthorizationT,
+        authentication: OptionalAnyAuthentication = None,
+        authorization: OptionalAnyAuthorization = None,
         impersonation: OptionalImpersonation = None,
         response: ErrorResponseT,
-    ) -> ReadFailedResourceOperation[
-        AnyErrorT, OptionalAnyAuthenticationT, OptionalAuthorizationT, ErrorResponseT
-    ]: ...
+    ) -> ReadFailedResourceOperation[AnyErrorT, ErrorResponseT]: ...
     @overload
     @classmethod
     def generate(
@@ -797,13 +653,11 @@ class FailedFactory(
         summary: str,
         error: AnyErrorT,
         connection_context: OptionalConnectionContext = None,
-        authentication: OptionalAnyAuthenticationT,
-        authorization: OptionalAuthorizationT,
+        authentication: OptionalAnyAuthentication = None,
+        authorization: OptionalAnyAuthorization = None,
         impersonation: OptionalImpersonation = None,
         response: ErrorResponseT,
-    ) -> UpdateFailedResourceOperation[
-        AnyErrorT, OptionalAnyAuthenticationT, OptionalAuthorizationT, ErrorResponseT
-    ]: ...
+    ) -> UpdateFailedResourceOperation[AnyErrorT, ErrorResponseT]: ...
     @overload
     @classmethod
     def generate(
@@ -818,13 +672,11 @@ class FailedFactory(
         summary: str,
         error: AnyErrorT,
         connection_context: OptionalConnectionContext = None,
-        authentication: OptionalAnyAuthenticationT,
-        authorization: OptionalAuthorizationT,
+        authentication: OptionalAnyAuthentication = None,
+        authorization: OptionalAnyAuthorization = None,
         impersonation: OptionalImpersonation = None,
         response: ErrorResponseT,
-    ) -> DeleteFailedResourceOperation[
-        AnyErrorT, OptionalAnyAuthenticationT, OptionalAuthorizationT, ErrorResponseT
-    ]: ...
+    ) -> DeleteFailedResourceOperation[AnyErrorT, ErrorResponseT]: ...
     @overload
     @classmethod
     def generate(
@@ -843,33 +695,25 @@ class FailedFactory(
         summary: str,
         error: AnyErrorT,
         connection_context: OptionalConnectionContext = None,
-        authentication: OptionalAnyAuthenticationT,
-        authorization: OptionalAuthorizationT,
+        authentication: OptionalAnyAuthentication = None,
+        authorization: OptionalAnyAuthorization = None,
         impersonation: OptionalImpersonation = None,
         response: ErrorResponseT,
     ) -> Union[
         CreateFailedResourceOperation[
             AnyErrorT,
-            OptionalAnyAuthenticationT,
-            OptionalAuthorizationT,
             ErrorResponseT,
         ],
         ReadFailedResourceOperation[
             AnyErrorT,
-            OptionalAnyAuthenticationT,
-            OptionalAuthorizationT,
             ErrorResponseT,
         ],
         UpdateFailedResourceOperation[
             AnyErrorT,
-            OptionalAnyAuthenticationT,
-            OptionalAuthorizationT,
             ErrorResponseT,
         ],
         DeleteFailedResourceOperation[
             AnyErrorT,
-            OptionalAnyAuthenticationT,
-            OptionalAuthorizationT,
             ErrorResponseT,
         ],
     ]: ...
@@ -891,33 +735,25 @@ class FailedFactory(
         summary: str,
         error: AnyErrorT,
         connection_context: OptionalConnectionContext = None,
-        authentication: OptionalAnyAuthenticationT,
-        authorization: OptionalAuthorizationT,
+        authentication: OptionalAnyAuthentication = None,
+        authorization: OptionalAnyAuthorization = None,
         impersonation: OptionalImpersonation = None,
         response: ErrorResponseT,
     ) -> Union[
         CreateFailedResourceOperation[
             AnyErrorT,
-            OptionalAnyAuthenticationT,
-            OptionalAuthorizationT,
             ErrorResponseT,
         ],
         ReadFailedResourceOperation[
             AnyErrorT,
-            OptionalAnyAuthenticationT,
-            OptionalAuthorizationT,
             ErrorResponseT,
         ],
         UpdateFailedResourceOperation[
             AnyErrorT,
-            OptionalAnyAuthenticationT,
-            OptionalAuthorizationT,
             ErrorResponseT,
         ],
         DeleteFailedResourceOperation[
             AnyErrorT,
-            OptionalAnyAuthenticationT,
-            OptionalAuthorizationT,
             ErrorResponseT,
         ],
     ]:
