@@ -16,7 +16,7 @@ class Limit(IntEnum):
 
 
 class Page(BaseModel):
-    page: Annotated[int, Field(1, ge=1, description="Page number, must be >= 1.")] = 1
+    page: Annotated[int, Field(1, ge=1, description="Page number, must be >= 1")] = 1
 
 
 class FlexibleLimit(BaseModel):
@@ -26,7 +26,7 @@ class FlexibleLimit(BaseModel):
 
 
 class StrictLimit(BaseModel):
-    limit: Limit = Field(Limit.LIM_10, description="Page limit.")
+    limit: Limit = Field(Limit.LIM_10, description="Page limit")
 
 
 class PageInfo(BaseModel):
