@@ -1,6 +1,6 @@
 from pydantic import Field
 from typing import Annotated
-from maleo.mixins.general import Descriptor
+from ..mixins.general import Descriptor
 from .enums import Code as SuccessCode
 
 
